@@ -4,6 +4,8 @@ import montecarlodata.settings as settings
 from montecarlodata.collector.commands import collector
 from montecarlodata.common.user import UserService
 from montecarlodata.config import ConfigManager
+from montecarlodata.discovery.commands import discovery
+from montecarlodata.iac.commands import monitors
 from montecarlodata.integrations.commands import integrations
 
 
@@ -61,3 +63,10 @@ entry_point.add_command(integrations)
 entry_point.add_command(configure)
 entry_point.add_command(validate)
 entry_point.add_command(collector)
+entry_point.add_command(discovery)
+entry_point.add_command(monitors)
+
+
+# to allow this to be run as a script within an IDE (for debugging)
+if __name__ == '__main__':
+    entry_point()
\ No newline at end of file
