@@ -1,10 +1,11 @@
 import traceback
+from functools import wraps
 from typing import Any, Optional, List
 
 import click
-from functools import wraps
 
 import montecarlodata.settings as settings
+from montecarlodata.common.data import MonolithResponse
 
 
 def manage_errors(func):
@@ -45,3 +46,13 @@ def complain_and_abort(message: str) -> None:
     """
     click.echo(f'Error - {message}')
     raise click.Abort()
+
+
+def abort_on_gql_errors(response: MonolithResponse):
+    """
+    Convenience utility to echo any gql errors and exit
+    """
+    if response.errors:
+        for error in response.errors:
+            echo_error(error.get('message'))
+        raise click.Abort()
