@@ -6,7 +6,7 @@ from montecarlodata.config import Config
 from montecarlodata.errors import complain_and_abort, manage_errors
 from montecarlodata.integrations.onboarding.base import BaseOnboardingService
 from montecarlodata.integrations.onboarding.fields import EXPECTED_TOGGLE_EVENTS_GQL_RESPONSE_FIELD
-from montecarlodata.queries.onboarding import TOGGLE_METADATA_EVENT_MUTATION
+from montecarlodata.queries.onboarding import TOGGLE_EVENT_MUTATION
 
 
 class EventsOnboardingService(BaseOnboardingService):
@@ -24,7 +24,7 @@ class EventsOnboardingService(BaseOnboardingService):
         if num_of_warehouses == 1:
             kwargs['dwId'] = self._user_service.warehouses[0]['uuid']
             variables = self._request_wrapper.convert_snakes_to_camels(kwargs)
-            status = self._request_wrapper.make_request(query=TOGGLE_METADATA_EVENT_MUTATION, variables=variables).get(
+            status = self._request_wrapper.make_request(query=TOGGLE_EVENT_MUTATION, variables=variables).get(
                 EXPECTED_TOGGLE_EVENTS_GQL_RESPONSE_FIELD, {}).get('success')
             if status:
                 click.echo(f"Success! {'Enabled' if kwargs['enable'] else 'Disabled'} events.")
