@@ -1,8 +1,8 @@
 # Queries related to managing the collector
 
 GENERATE_COLLECTOR_TEMPLATE = """
-mutation generateCollectorTemplate {
-  generateCollectorTemplate {
+mutation generateCollectorTemplate($region:String) {
+  generateCollectorTemplate(region:$region) {
     dc {
       templateLaunchUrl
       stackArn
