@@ -14,6 +14,8 @@ query getUser {
         customerAwsAccountId
         warehouses {
           uuid
+          name
+          connectionType
           connections {
             uuid
             type
