@@ -9,6 +9,9 @@ MCD_VERBOSE_ERRORS = os.getenv('MCD_VERBOSE_ERRORS', False) in (True, 'true', 'T
 # MCD API endpoint
 MCD_API_ENDPOINT = os.getenv('MCD_API_ENDPOINT', 'https://api.getmontecarlo.com/graphql')
 
+# MCD ID header (for use in local development and testing)
+MCD_USER_ID_HEADER = os.getenv('MCD_USER_ID_HEADER')
+
 # MCD API ID. Overwrites config-file
 MCD_DEFAULT_API_ID = os.getenv('MCD_DEFAULT_API_ID')
 
@@ -39,3 +42,23 @@ HELP_FLAG = '--help'
 
 # Option file flag
 OPTION_FILE_FLAG = '--option-file'
+
+
+"""Monitors as code configs"""
+DEFAULT_MONTECARLO_MONITOR_CONFIG_VERSION = 1
+
+PROJECT_CONFIG_FILENAME = 'montecarlo.yml'
+
+TARGET_DIRECTORY_NAME = 'target'
+
+DEFAULT_INCLUDE_PATTERNS = [
+    '**/*.yaml',
+    '**/*.yml',
+]
+
+DEFAULT_EXCLUDE_PATTERNS = [
+    'target/*',
+    'dbt_project.yml',
+    'montecarlo.yml'
+]
+
