@@ -1,13 +1,14 @@
 import json
 import re
-from typing import Dict, Optional, List
+from typing import Dict, Optional, List, Iterable
 
 import boto3
 import requests
 from retry import retry
 
 import montecarlodata.settings as settings
-from montecarlodata.errors import manage_errors, complain_and_abort
+from montecarlodata.common.data import MonolithResponse
+from montecarlodata.errors import manage_errors, complain_and_abort, abort_on_gql_errors
 
 
 class Wrapper:
@@ -33,6 +34,17 @@ class GqlWrapper(Wrapper):
                 complain_and_abort(response['errors'])
             return response['data']
 
+    def make_request_v2(self, query: str, operation: str, variables: Optional[Dict] = None) -> MonolithResponse:
+        """
+        Make a GraphQl request to the MCD API and parse out the results into data and errors. Aborts on error if set.
+        """
+        response = self._make_request(query=query, variables=self.convert_snakes_to_camels(variables))
+        parsed_response = MonolithResponse(data=response.get('data', {}).get(operation), errors=response.get('errors'))
+
+        if self._abort_on_error:
+            abort_on_gql_errors(parsed_response)
+        return parsed_response
+
     @staticmethod
     def convert_snakes_to_camels(dict_: Dict) -> Dict:
         """
@@ -45,6 +57,9 @@ class GqlWrapper(Wrapper):
         headers = {'x-mcd-id': self._mcd_id, 'x-mcd-token': self._mcd_token, 'Content-Type': 'application/json'}
         payload = {'query': query, 'variables': variables or {}}
 
+        if settings.MCD_USER_ID_HEADER:
+            headers = {'user-id': settings.MCD_USER_ID_HEADER}  # override for local development
+
         response = self._post(headers=headers, payload=payload)
         response.raise_for_status()
 
@@ -56,9 +71,18 @@ class GqlWrapper(Wrapper):
 
 
 class AwsClientWrapper(Wrapper):
+    _CF_CREATE_WAITER = 'stack_create_complete'
     _CF_UPDATE_WAITER = 'stack_update_complete'
     _DEFAULT_WAITER_CONFIG = {'Delay': 5, 'MaxAttempts': 720}
+    _DEFAULT_CAPABILITIES = 'CAPABILITY_IAM'
+    _STACK_CREATE_STATE = 'CREATE_COMPLETE'
     _STACK_UPDATE_STATE = 'UPDATE_COMPLETE'
+    # Map from the shorthand state form available in the AWS CLI to the actual states.
+    _EMR_STATES = {
+        'active': ['STARTING', 'BOOTSTRAPPING', 'RUNNING', 'WAITING', 'TERMINATING'],
+        'terminated': ['TERMINATED'],
+        'failed': ['TERMINATED_WITH_ERRORS']
+    }
 
     def __init__(self, profile_name: Optional[str] = None, region_name: Optional[str] = None,
                  session: Optional[boto3.session.Session] = None):
@@ -89,20 +113,37 @@ class AwsClientWrapper(Wrapper):
         return self.get_stack_details(stack_id)['Stacks'][0].get('Parameters')
 
     @manage_errors
-    def upgrade_stack(self, stack_id: str, template_link: str, parameters: List[Dict],
-                      capabilities: Optional[str] = 'CAPABILITY_IAM') -> bool:
+    def create_stack(self, stack_name: str, template_link: str, termination_protection: bool,
+                     parameters: Optional[List[Dict]] = None) -> bool:
+        """
+        Attempts to deploy the DC stack - returning True on success
+        """
+        deployment_options = dict(
+            StackName=stack_name,
+            TemplateURL=template_link,
+            Capabilities=[self._DEFAULT_CAPABILITIES],
+            EnableTerminationProtection=termination_protection
+        )
+        if parameters:
+            deployment_options['Parameters'] = parameters
+
+        response = self._session.client('cloudformation').create_stack(**deployment_options)
+        stack_id = response['StackId']
+        return self._wait_on_stacks(stack_id=stack_id, waiter=self._CF_CREATE_WAITER,
+                                    success_state=self._STACK_CREATE_STATE)
+
+    @manage_errors
+    def upgrade_stack(self, stack_id: str, template_link: str, parameters: List[Dict]) -> bool:
         """
         Attempts to upgrade the DC stack - returning True on success
         """
         self._session.client('cloudformation').update_stack(StackName=stack_id, TemplateURL=template_link,
-                                                            Capabilities=[capabilities], Parameters=parameters)
-        self._session.client('cloudformation').get_waiter(self._CF_UPDATE_WAITER).wait(StackName=stack_id,
-                                                                                       WaiterConfig=self._DEFAULT_WAITER_CONFIG)
-
-        if self.get_stack_details(stack_id)['Stacks'][0]['StackStatus'] == self._STACK_UPDATE_STATE:
-            return True
-        return False
+                                                            Capabilities=[self._DEFAULT_CAPABILITIES],
+                                                            Parameters=parameters)
+        return self._wait_on_stacks(stack_id=stack_id, waiter=self._CF_UPDATE_WAITER,
+                                    success_state=self._STACK_UPDATE_STATE)
 
+    @manage_errors
     def deploy_gateway(self, gateway_id: str, stage: Optional[str] = 'prod') -> None:
         """
         Attempts to deploy the DC gateway
@@ -132,6 +173,23 @@ class AwsClientWrapper(Wrapper):
         return self._session.client('iam').put_role_policy(RoleName=role_name, PolicyName=policy_name,
                                                            PolicyDocument=policy_doc)
 
+    @manage_errors
+    def get_emr_cluster_details(self, created_after: Optional[str] = None, states: Optional[List] = None
+                                ) -> Iterable[Dict]:
+        """
+        Retrieves details of all EMR clusters
+        """
+        client = self._session.client('emr')
+        params = {}
+        if created_after:
+            params['CreatedAfter'] = created_after
+        if states:
+            params['ClusterStates'] = [mapped for state in states for mapped in self._EMR_STATES[state]]
+        pages = client.get_paginator('list_clusters').paginate(**params)
+        for page in pages:
+            for cluster in page['Clusters']:
+                yield client.describe_cluster(ClusterId=cluster['Id']).get('Cluster')
+
     @manage_errors
     def _test_if_region_is_set(self) -> None:
         """
@@ -146,3 +204,11 @@ class AwsClientWrapper(Wrapper):
         """
         session_args = (('profile_name', profile_name), ('region_name', region_name))
         return boto3.session.Session(**{k: v for k, v in session_args if v})  # throws ProfileNotFound if invalid
+
+    def _wait_on_stacks(self, stack_id: str, waiter: str, success_state: str) -> bool:
+        """
+        Wait for stack to finish operation
+        """
+        self._session.client('cloudformation').get_waiter(waiter).wait(StackName=stack_id,
+                                                                       WaiterConfig=self._DEFAULT_WAITER_CONFIG)
+        return self.get_stack_details(stack_id)['Stacks'][0]['StackStatus'] == success_state
